@@ -1,7 +1,6 @@
 #!/usr/bin/env python3
 
 import argparse
-import json
 import csv
 import sys
 from time import sleep
@@ -9,7 +8,7 @@ from datetime import timedelta
 from dictor import dictor
 from requests_cache import CachedSession
 
-intro = '''
+INTRO = '''
   ▓░░░█▀▀░█▀▀▄░░▀░░█▀▀▀░█░░░░▀█▀░
   ▓░░░█▀░░█▄▄▀░░█▀░█░▀▄░█▀▀█░░█░░
   ▓░░░▀░░░▀░▀▀░▀▀▀░▀▀▀▀░▀░░▀░░▀░░
@@ -17,9 +16,9 @@ intro = '''
   ▓░█░░░█▄▄▀░█▄▄█░▀▄█▄▀░█░░█▀▀░█▄▄▀
   ▓░▀▀▀░▀░▀▀░▀░░▀░░▀░▀░░▀▀░▀▀▀░▀░▀▀
 '''
-print(intro)
+print(INTRO)
 
-class Logger():
+class Logger:
     def __init__(self):
         self.terminal = sys.stdout
         self.log = open("frightcrawler-output.log", "a")
@@ -70,7 +69,9 @@ def main():
         cardlist = csv.reader(cardlist_csv, delimiter=',')
         next(cardlist)
         print('  Processing ' + args.csv_file +' CSV file for ' + args.format + ' format...\n')
-        scry_cache = CachedSession(backend='sqlite', cache_name='scryfall-cache', expire_after=timedelta(days=3))
+        scry_cache = CachedSession(backend='sqlite',
+                                   cache_name='scryfall-cache',
+                                   expire_after=timedelta(days=3))
         for row in cardlist:
             if args.helvault:
                 scry_id = 'https://api.scryfall.com/cards/' + row[6]
@@ -83,9 +84,9 @@ def main():
                 foil_status = row[7]
 
             if foil_status == '1' or foil_status == 'foil':
-                foil = "◆ "
+                foil = "◆"
             else:
-                foil = '● '
+                foil = '●'
 
             scry_api = scry_cache.request('GET', scry_id)
             scry_json = scry_api.json()
@@ -94,121 +95,121 @@ def main():
                 card_status = dictor(scry_json, 'legalities', search=args.format, checknone=True)
                 set_name = dictor(scry_json, 'set_name')
                 if card_status == ['legal']:
-                    print('  ▓▒░░░    Legal   ', foil, card_name, ' ◄', set_name, '►')
+                    print('  ▓▒░░░    Legal   ', foil, card_name, '◄', set_name, '►')
                 elif card_status == ['not_legal']:
-                    print('  ▓▒░░░  Not legal ', foil, card_name, ' ◄', set_name, '►')
+                    print('  ▓▒░░░  Not legal ', foil, card_name, '◄', set_name, '►')
 
             if args.commander:
                 card_status = dictor(scry_json, 'legalities', search=args.format, checknone=True)
                 set_name = dictor(scry_json, 'set_name')
                 if card_status == ['legal']:
-                    print('  ▓▒░░░    Legal   ', foil, card_name, ' ◄', set_name, '►')
+                    print('  ▓▒░░░    Legal   ', foil, card_name, '◄', set_name, '►')
                 elif card_status == ['not_legal']:
-                    print('  ▓▒░░░  Not legal ', foil, card_name, ' ◄', set_name, '►')
+                    print('  ▓▒░░░  Not legal ', foil, card_name, '◄', set_name, '►')
 
             if args.duel:
                 card_status = dictor(scry_json, 'legalities', search=args.format, checknone=True)
                 set_name = dictor(scry_json, 'set_name')
                 if card_status == ['legal']:
-                    print('  ▓▒░░░    Legal   ', foil, card_name, ' ◄', set_name, '►')
+                    print('  ▓▒░░░    Legal   ', foil, card_name, '◄', set_name, '►')
                 elif card_status == ['not_legal']:
-                    print('  ▓▒░░░  Not legal ', foil, card_name, ' ◄', set_name, '►')
+                    print('  ▓▒░░░  Not legal ', foil, card_name, '◄', set_name, '►')
 
             if args.future:
                 card_status = dictor(scry_json, 'legalities', search=args.format, checknone=True)
                 set_name = dictor(scry_json, 'set_name')
                 if card_status == ['legal']:
-                    print('  ▓▒░░░    Legal   ', foil, card_name, ' ◄', set_name, '►')
+                    print('  ▓▒░░░    Legal   ', foil, card_name, '◄', set_name, '►')
                 elif card_status == ['not_legal']:
-                    print('  ▓▒░░░  Not legal ', foil, card_name, ' ◄', set_name, '►')
+                    print('  ▓▒░░░  Not legal ', foil, card_name, '◄', set_name, '►')
 
             if args.gladiator:
                 card_status = dictor(scry_json, 'legalities', search=args.format, checknone=True)
                 set_name = dictor(scry_json, 'set_name')
                 if card_status == ['legal']:
-                    print('  ▓▒░░░    Legal   ', foil, card_name, ' ◄', set_name, '►')
+                    print('  ▓▒░░░    Legal   ', foil, card_name, '◄', set_name, '►')
                 elif card_status == ['not_legal']:
-                    print('  ▓▒░░░  Not legal ', foil, card_name, ' ◄', set_name, '►')
+                    print('  ▓▒░░░  Not legal ', foil, card_name, '◄', set_name, '►')
 
             if args.historic:
                 card_status = dictor(scry_json, 'legalities', search=args.format, checknone=True)
                 set_name = dictor(scry_json, 'set_name')
                 if card_status == ['legal']:
-                    print('  ▓▒░░░    Legal   ', foil, card_name, ' ◄', set_name, '►')
+                    print('  ▓▒░░░    Legal   ', foil, card_name, '◄', set_name, '►')
                 elif card_status == ['not_legal']:
-                    print('  ▓▒░░░  Not legal ', foil, card_name, ' ◄', set_name, '►')
+                    print('  ▓▒░░░  Not legal ', foil, card_name, '◄', set_name, '►')
 
             if args.legacy:
                 card_status = dictor(scry_json, 'legalities', search=args.format, checknone=True)
                 set_name = dictor(scry_json, 'set_name')
                 if card_status == ['legal']:
-                    print('  ▓▒░░░    Legal   ', foil, card_name, ' ◄', set_name, '►')
+                    print('  ▓▒░░░    Legal   ', foil, card_name, '◄', set_name, '►')
                 elif card_status == ['not_legal']:
-                    print('  ▓▒░░░  Not legal ', foil, card_name, ' ◄', set_name, '►')
+                    print('  ▓▒░░░  Not legal ', foil, card_name, '◄', set_name, '►')
 
             if args.modern:
                 card_status = dictor(scry_json, 'legalities', search=args.format, checknone=True)
                 set_name = dictor(scry_json, 'set_name')
                 if card_status == ['legal']:
-                    print('  ▓▒░░░    Legal   ', foil, card_name, ' ◄', set_name, '►')
+                    print('  ▓▒░░░    Legal   ', foil, card_name, '◄', set_name, '►')
                 elif card_status == ['not_legal']:
-                    print('  ▓▒░░░  Not legal ', foil, card_name, ' ◄', set_name, '►')
+                    print('  ▓▒░░░  Not legal ', foil, card_name, '◄', set_name, '►')
 
             if args.oldschool:
                 card_status = dictor(scry_json, 'legalities', search=args.format, checknone=True)
                 set_name = dictor(scry_json, 'set_name')
                 if card_status == ['legal']:
-                    print('  ▓▒░░░    Legal   ', foil, card_name, ' ◄', set_name, '►')
+                    print('  ▓▒░░░    Legal   ', foil, card_name, '◄', set_name, '►')
                 elif card_status == ['not_legal']:
-                    print('  ▓▒░░░  Not legal ', foil, card_name, ' ◄', set_name, '►')
+                    print('  ▓▒░░░  Not legal ', foil, card_name, '◄', set_name, '►')
 
             if args.pauper:
                 card_status = dictor(scry_json, 'legalities', search=args.format, checknone=True)
                 set_name = dictor(scry_json, 'set_name')
                 if card_status == ['legal']:
-                    print('  ▓▒░░░    Legal   ', foil, card_name, ' ◄', set_name, '►')
+                    print('  ▓▒░░░    Legal   ', foil, card_name, '◄', set_name, '►')
                 elif card_status == ['not_legal']:
-                    print('  ▓▒░░░  Not legal ', foil, card_name, ' ◄', set_name, '►')
+                    print('  ▓▒░░░  Not legal ', foil, card_name, '◄', set_name, '►')
 
             if args.penny:
                 card_status = dictor(scry_json, 'legalities', search=args.format, checknone=True)
                 set_name = dictor(scry_json, 'set_name')
                 if card_status == ['legal']:
-                    print('  ▓▒░░░    Legal   ', foil, card_name, ' ◄', set_name, '►')
+                    print('  ▓▒░░░    Legal   ', foil, card_name, '◄', set_name, '►')
                 elif card_status == ['not_legal']:
-                    print('  ▓▒░░░  Not legal ', foil, card_name, ' ◄', set_name, '►')
+                    print('  ▓▒░░░  Not legal ', foil, card_name, '◄', set_name, '►')
 
             if args.pioneer:
                 card_status = dictor(scry_json, 'legalities', search=args.format, checknone=True)
                 set_name = dictor(scry_json, 'set_name')
                 if card_status == ['legal']:
-                    print('  ▓▒░░░    Legal   ', foil, card_name, ' ◄', set_name, '►')
+                    print('  ▓▒░░░    Legal   ', foil, card_name, '◄', set_name, '►')
                 elif card_status == ['not_legal']:
-                    print('  ▓▒░░░  Not legal ', foil, card_name, ' ◄', set_name, '►')
+                    print('  ▓▒░░░  Not legal ', foil, card_name, '◄', set_name, '►')
 
             if args.premodern:
                 card_status = dictor(scry_json, 'legalities', search=args.format, checknone=True)
                 set_name = dictor(scry_json, 'set_name')
                 if card_status == ['legal']:
-                    print('  ▓▒░░░    Legal   ', foil, card_name, ' ◄', set_name, '►')
+                    print('  ▓▒░░░    Legal   ', foil, card_name, '◄', set_name, '►')
                 elif card_status == ['not_legal']:
-                    print('  ▓▒░░░  Not legal ', foil, card_name, ' ◄', set_name, '►')
+                    print('  ▓▒░░░  Not legal ', foil, card_name, '◄', set_name, '►')
 
             if args.standard:
                 card_status = dictor(scry_json, 'legalities', search=args.format, checknone=True)
                 set_name = dictor(scry_json, 'set_name')
                 if card_status == ['legal']:
-                    print('  ▓▒░░░    Legal   ', foil, card_name, ' ◄', set_name, '►')
+                    print('  ▓▒░░░    Legal   ', foil, card_name, '◄', set_name, '►')
                 elif card_status == ['not_legal']:
-                    print('  ▓▒░░░  Not legal ', foil, card_name, ' ◄', set_name, '►')
+                    print('  ▓▒░░░  Not legal ', foil, card_name, '◄', set_name, '►')
 
             if args.vintage:
                 card_status = dictor(scry_json, 'legalities', search=args.format, checknone=True)
                 set_name = dictor(scry_json, 'set_name')
                 if card_status == ['legal']:
-                    print('  ▓▒░░░    Legal   ', foil, card_name, ' ◄', set_name, '►')
+                    print('  ▓▒░░░    Legal   ', foil, card_name, '◄', set_name, '►')
                 elif card_status == ['not_legal']:
-                    print('  ▓▒░░░  Not legal ', foil, card_name, ' ◄', set_name, '►')
+                    print('  ▓▒░░░  Not legal ', foil, card_name, '◄', set_name, '►')
 
             sleep(.1) #respect API rate limits
 
